@@ -131,6 +131,13 @@ class Extension(metaclass=abc.ABCMeta):
         """Parse intercepted commands."""
         pass
 
+    def file_exists(self, file_name):
+        '''File exists in the working directory'''
+        if not os.path.isabs(file_name):
+            file_name = os.path.join(self.work_dir, file_name)
+
+        return os.path.exists(file_name)
+
     def load_data(self, file_name, raise_exception=True):
         """Load file by name."""
 
@@ -467,6 +474,9 @@ class Extension(metaclass=abc.ABCMeta):
                     # skip sleep only for very small projects
                     time.sleep(0.1)
 
+        # Clean line
+        print(" " * 79, end="\r")
+
     @staticmethod
     def get_all_extensions():
         """Get all extension classes."""
