@@ -13,11 +13,7 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-try:
-    import cchardet as chardet
-except ImportError:
-    import chardet
-
+import charset_normalizer
 import os
 import re
 import shlex
@@ -234,7 +230,7 @@ class CL(Compiler):
         if self.conf.get("Compiler.deps_encoding"):
             encoding = self.conf.get("Compiler.deps_encoding")
         else:
-            encoding = chardet.detect(output_bytes)["encoding"]
+            encoding = charset_normalizer.detect(output_bytes)["encoding"]
 
         if not encoding:
             return deps
@@ -266,7 +262,7 @@ class CL(Compiler):
             encoding = self.conf.get("CL.pre_encoding")
         else:
             rawdata = open(pre_to, "rb").read()
-            encoding = chardet.detect(rawdata)["encoding"]
+            encoding = charset_normalizer.detect(rawdata)["encoding"]
 
         # Normalize paths in line directives
         self.__normalize_paths(pre_to, cmd["cwd"], encoding)
