@@ -22,4 +22,9 @@ class CXX(CC):
     __version__ = "1"
 
     def parse(self, cmds_file):
-        super(CC, self).parse(cmds_file, self.conf.get("CXX.which_list", []))
+        which_list = list(self.conf.get("CXX.which_list", []))
+
+        if self.conf.get("CXX.process_ccache"):
+            which_list.append("ccache")
+
+        super(CC, self).parse(cmds_file, which_list)
