@@ -29,10 +29,10 @@ from clade.extensions.opts import filter_opts
 
 
 class Info(Extension):
-    always_requires = ["SrcGraph", "Storage"]
+    always_requires = ["SrcGraph", "Storage", "Alternatives"]
     requires = always_requires + ["CC", "CL"]
 
-    __version__ = "3"
+    __version__ = "4"
 
     def __init__(self, work_dir, conf=None):
         if not conf:
@@ -102,12 +102,14 @@ class Info(Extension):
     def parse(self, cmds_file):
         self.__check_cif()
 
-        cmds = list(self.extensions["SrcGraph"].load_all_cmds())
+        cmds = list(self.extensions["SrcGraph"].load_compilation_cmds())
         total_cmds = len(cmds)
 
         if not cmds:
             raise RuntimeError("There are no parsed compiler commands")
 
+        self.storage_dir = self.extensions["Storage"].get_storage_dir()
+
         self.log(f"Parsing {total_cmds} commands")
         self.execute_in_parallel(cmds, Info._run_cif, total_objs=total_cmds)
 
@@ -127,7 +129,14 @@ class Info(Extension):
         if not os.path.exists(self.err_log):
             self.log("CIF finished without errors")
         else:
-            self.log("CIF finished with errors")
+            # Count number of command on which CIF failed
+            with open(self.err_log, "r") as log_fh:
+                count = 0
+                for line in log_fh:
+                    if "Aspectator failed at" in line:
+                        count += 1
+
+            self.warning(f"CIF failed on {count} commands")
 
         self.__normalize_cif_output()
 
@@ -168,12 +177,13 @@ class Info(Extension):
                 continue
 
             cif_out = os.path.join(
-                tmp_dir, os.path.basename(storage_cmd_in.lstrip(os.sep)) + ".o"
+                tmp_dir, os.path.basename(cif_in.lstrip(os.sep)) + ".o"
             )
 
             cif_env = {
                 "CIF_INFO_DIR": self.cif_output_dir,
-                "C_FILE": cmd_in
+                "C_FILE": cmd_in,
+                "CMD_ID": cmd["id"]
             }
 
             cif_args = [
@@ -234,6 +244,8 @@ class Info(Extension):
                 self.__save_log(cmd["id"], cwd, cif_args, cif_env, str(e), self.err_log)
                 self.__save_log(cmd["id"], cwd, cif_args, cif_env, str(e), self.cif_log)
 
+        shutil.rmtree(tmp_dir)
+
         # Force garbage collector to work
         gc.collect()
 
@@ -272,11 +284,11 @@ class Info(Extension):
             log_fh.write("\n\n")
 
     def __find_cif_output(self):
-        cif_output = []
+        cif_output = set()
 
         for root, _, filenames in os.walk(self.work_dir):
             for filename in fnmatch.filter(filenames, "*.txt"):
-                cif_output.append(os.path.join(root, filename))
+                cif_output.add(os.path.join(root, filename))
 
         return cif_output
 
@@ -284,7 +296,14 @@ class Info(Extension):
         cif_output = self.__find_cif_output()
 
         total_files = len(cif_output)
-        storage = self.extensions["Storage"].get_storage_dir()
+
+        # All paths in CIF output should be formatted the following way:
+        # - CIF_OUTPUT_DIR + STORAGE_PATH + ABS_FILE_PATH
+        # But sometimes, due to the absolute imports, this becomes
+        # - CIF_OUTPUT_DIR + ABS_FILE_PATH
+        # And information about one file (ABS_FILE_PATH) can be splitted
+        # into several paths. self.__fix_wrong_paths compines and fixes it.
+        self.__fix_wrong_paths(cif_output)
 
         # Normalize all small cif output files
         self.log(f"Normalizing {total_files} files")
@@ -304,40 +323,72 @@ class Info(Extension):
             with zipfile.ZipFile(file, "w") as zip_fh:
                 for output_file in output_files:
                     # Remove unnecessary prefixes from path inside archive
-                    arcname = output_file.replace(storage, "")
-                    arcname = arcname.replace(self.cif_output_dir, "")
-
+                    arcname = self.__normalize_path(output_file)
                     zip_fh.write(output_file, arcname=arcname)
 
         # Remove cif output directory
         if os.path.exists(self.cif_output_dir):
             shutil.rmtree(self.cif_output_dir)
 
+    def __fix_wrong_paths(self, cif_output):
+        # Set of files to remove from cif_output
+        to_remove = set()
+
+        paths = dict()
+        for output_file in cif_output:
+            npath = self.__normalize_path(output_file)
+
+            if npath not in paths:
+                # Everyting is ok
+                paths[npath] = output_file
+                continue
+
+            # Otherwise, information about output_file is also stored
+            # in paths[npath]. Combine these 2 files:
+            normal_path = paths[npath]
+
+            with open(normal_path, "a") as normal_fh:
+                with open(output_file, "r") as wrong_fh:
+                    for line in wrong_fh:
+                        normal_fh.write(line)
+
+            os.remove(output_file)
+            to_remove.add(output_file)
+
+        for output_file in to_remove:
+            cif_output.remove(output_file)
+
+    def __normalize_path(self, path):
+        npath = path.replace(self.cif_output_dir, "")
+        return npath.replace(self.storage_dir, "")
+
     def iter_init_global(self):
-        """Yield C_FILE, signature, type, json string with initialisations"""
-        regex = re.compile(r"\"(.*?)\" \"(.*?);\" (\S*) (.*)\n")
+        """Yield C_FILE, signature, cmd_id, type, json string with initialisations"""
+        regex = re.compile(r"\"(.*?)\" \"(.*?);\" (\S*) (\S*) (.*)\n")
 
         for content in self.__iter_file_regex(self.init_global, regex):
+            # non-static functions are treated as extern by compiler
+            content[3] = "extern" if content[3] != "static" else "static"
             yield content
 
     def iter_definitions(self):
-        """Yield src_file, func, def_line, func_type, signature"""
+        """Yield src_file, cmd_id, func, def_line, func_type, signature"""
 
-        regex = re.compile(r"\"(.*?)\" (\S*) (\S*) (\S*) ([^']*)\n")
+        regex = re.compile(r"\"(.*?)\" (\S*) (\S*) (\S*) (\S*) ([^']*)\n")
 
         for content in self.__iter_file_regex(self.execution, regex):
             # non-static functions are treated as extern by compiler
-            content[3] = "extern" if content[3] != "static" else "static"
+            content[4] = "extern" if content[4] != "static" else "static"
             yield content
 
     def iter_declarations(self):
-        """Yield decl_file, decl_name, decl_line, decl_type, decl_signature"""
+        """Yield decl_file, cmd_id, decl_name, decl_line, decl_type, decl_signature"""
 
-        regex = re.compile(r"\"(.*?)\" (\S*) (\S*) (\S*) ([^']*)\n")
+        regex = re.compile(r"\"(.*?)\" (\S*) (\S*) (\S*) (\S*) ([^']*)\n")
 
         for content in self.__iter_file_regex(self.decl, regex):
             # non-static functions are treated as extern by compiler
-            content[3] = "extern" if content[3] != "static" else "static"
+            content[4] = "extern" if content[4] != "static" else "static"
             yield content
 
     def iter_exported(self):
@@ -349,14 +400,14 @@ class Info(Extension):
             yield content
 
     def iter_calls(self):
-        """Yield context_file, context_func, func, call_line, call_type, args"""
+        """Yield context_file, context_cmd_id, context_func, func, call_line, call_type, args"""
 
-        regex = re.compile(r'\"(.*?)\" (\S*) (\S*) (\S*) (\S*) (.*)')
+        regex = re.compile(r'\"(.*?)\" (\S*) (\S*) (\S*) (\S*) (\S*) (.*)')
         args_regex = re.compile(r"actual_arg_func_name(\d+)=\s*(\w+)\s*")
 
         for content in self.__iter_file_regex(self.call, regex):
             # non-static functions are treated as extern by compiler
-            content[4] = "extern" if content[4] != "static" else "static"
+            content[5] = "extern" if content[5] != "static" else "static"
 
             # Replace last element of content list (string with arguments)
             # with list of these arguments
@@ -373,11 +424,14 @@ class Info(Extension):
             yield content
 
     def iter_functions_usages(self):
-        """Yield context_file, context_func, func, line"""
+        """Yield context_file, context_cmd_id, context_func, func, line, call_type"""
 
-        regex = re.compile(r'\"(.*?)\" (\S*) (\S*) (\S*)')
+        regex = re.compile(r'\"(.*?)\" (\S*) (\S*) (\S*) (\S*) (\S*)')
 
         for content in self.__iter_file_regex(self.use_func, regex):
+            # non-static functions are treated as extern by compiler
+            content[5] = "extern" if content[5] != "static" else "static"
+
             yield content
 
     def iter_macros_definitions(self):
@@ -397,6 +451,9 @@ class Info(Extension):
         for orig_content in self.__iter_file_regex(self.expand, regex):
             content = list(orig_content)
 
+            # Make def_file canonical
+            content[1] = self.extensions["Alternatives"].get_canonical_path(content[1])
+
             args = list()
 
             # Replace last element of content list (string with arguments)
@@ -412,7 +469,7 @@ class Info(Extension):
             yield content
 
     def iter_typedefs(self):
-        """Yeild scope_file, declaration"""
+        """Yield scope_file, declaration"""
 
         regex = re.compile(r'\"(.*?)\" typedef (.*)')
 
@@ -429,7 +486,11 @@ class Info(Extension):
                         self.error("CIF output has unexpected format: {!r}".format(line))
                         raise SyntaxError
 
-                    yield list(m.groups())
+                    content = list(m.groups())
+
+                    # First index is always a path: make it canonical
+                    content[0] = self.extensions["Alternatives"].get_canonical_path(content[0])
+                    yield content
 
     def __iter_file(self, file, zip_fh):
         # Path to the source file is encoded in the path to the CIF output file
