@@ -34,6 +34,7 @@ gcc_opts = [
     "-Xpreprocessor",
     "-Xassembler",
     "-l",
+    "-L",
     "-Xlinker",
     "-T",
     "-u",
@@ -475,6 +476,20 @@ cl_opts = [
     "-U",
 ]
 
+install_opts = [
+    "-g",
+    "--group",
+    "-m",
+    "--mode",
+    "-o",
+    "--owner",
+    "---strip-program",
+    "-S",
+    "--suffix",
+    "-t",
+    "--target-directory",
+]
+
 cl_preprocessor_deps_opts = ["/EP", "-EP", "/E", "-E", "/P", "-P"]
 
 requires_value = {
@@ -485,6 +500,7 @@ requires_value = {
     "Objcopy": set(objcopy_opts),
     "CL": set(cl_opts),
     "Link": set(),
+    "Install": set(install_opts)
 }
 
 # Some options require multiple values
